package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.34.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.34.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@("`0`````````````#`!8````!````````(O``````````0```````
M`+&0``````!``#@`"0!``!H`&0````8````$`````````$``````````0```
M``````!``````````?@````````!^``````````(`````P````0````````"
M.`````````(X`````````C@`````````#P`````````/``````````$````!
M````!0```````````````````````````````````````*>H````````IZ@`
M```````0``````$````&````````J[````````"[L````````+NP````````
M!-`````````4^````````!```````@````8```````"KP````````+O`````
M````N\`````````"``````````(```````````@````$````!`````````)(
M`````````D@````````"2`````````!$`````````$0`````````!&1TY5``
M```$````````H1@```````"A&````````*$8`````````-P`````````W```
M```````$9'3E40````8`````````````````````````````````````````
M`````````````````````!!D=.52````!````````*NP````````N[``````
M``"[L`````````10````````!%```````````2]L:6(O;&0V-"YS;RXQ````
M```$````%`````-'3E4`&0Y66(-S.3-+2\H8090CZ?H>@"\````$````$```
M``%'3E4```````````,````"```````````````1````1`````0````(A`1`
M!0`0$""$`(:`!``"*`@$(`D```F""`(`ND$0@(@`````````1````$<```!*
M````2P```%(```!3````5`````````!6````5P```%@```!9````6@```%P`
M`````````!_?Q6XM1][.?)I_:[:;Q2Y\U&34#N3_(1Q8<=D!QD?B;XL!LL#C
M2ZR'U_I"+#_EPGR2X[I@;*'[UD,):V;,KV?LU45"TW`'B>W;8C/,)8P5"Y<Z
M#9N<J7\*`J?@4)X::TG[X*,`````````````````````````````````````
M`P``"P```````!E8``````````````-Q$@``````````````````````````
M``(4$@````````````````````````````",$0``````````````````````
M``````&:$@````````````````````````````*J$@``````````````````
M``````````#A$0````````````````````````````&,$@``````````````
M``````````````'[$@````````````````````````````"]$@``````````
M``````````````````&W$@````````````````````````````*4$@``````
M``````````````````````&A$@`````````````````````````````!(```
M``````````````````````````'T$@````````````````````````````!G
M$@````````````````````````````*'$@``````````````````````````
M``#&$@````````````````````````````)&$@``````````````````````
M``````&%$@````````````````````````````*:$@``````````````````
M``````````%+$@````````````````````````````%A$@``````````````
M``````````````"4$@`````````````````````````````0(```````````
M``````````````````(L$@````````````````````````````$L$@``````
M``````````````````````"*$0````````````````````````````$U$@``
M```````````````````````````L(`````````````````````````````"=
M$@````````````````````````````(>$@``````````````````````````
M``%9$@````````````````````````````$`$@``````````````````````
M``````%^$@````````````````````````````'*$@``````````````````
M``````````$;$@````````````````````````````(W$@``````````````
M``````````````"S$@````````````````````````````!8(@``````````
M``````````````````):$@````````````````````````````)/$@``````
M``````````````````````$\$@````````````````````````````)4$@``
M``````````````````````````%I$@````````````````````````````(&
M$@````````````````````````````++$@``````````````````````````
M``!Y$@````````````````````````````%W$@``````````````````````
M``````)R$@````````````````````````````"<$@``````````````````
M``````````#:$@````````````````````````````#L$@``````````````
M``````````````*V$@````````````````````````````*/$@``````````
M``````````````````'H$@````````````````````````````(9$@``````
M``````````````````````*`$@````````````````````````````';$0``
M``````````````````````````"D$@````````````````````````````#,
M$@````````````````````````````$0$@``````````````````````````
M``"K$@````````````````````````````&H$@``````````````````````
M``````!&$@````````````````````````````%P$@``````````````````
M``````````)K$0````````````````````````````-Z$@``#0```````%&`
M`````````0H```//$@``#0```````%4@````````"9P```!3$@``#0``````
M`""@`````````DX```+Q$@``#0```````$2```````````8```,/$@``#0``
M`````%[``````````H````/U$@``#0```````$20`````````KX```.U$```
M%P```````,"```````````````,"$@``#0```````$=0`````````$0```,E
M$@``#0```````$Z@`````````(P```.&$0``#P```````&%\``````````0`
M``.B$@``#0```````%*0`````````3````.M$@``#0```````$-`````````
M`#P```/*$```%P```````-"H``````````````/C$@``#0```````$]@````
M`````:0```.5$```%@```````,````````````````-)$@``#0```````$>@
M`````````6X```/<$```%@```````,"```````````````0"$0``%@``````
M`,!X``````````@```.;$@``#0```````"+P``````````````/!$@``#0``
M`````%$0`````````&P```.7(```%@```````,````````````````-?$@``
M#0```````$\P`````````"P```,S$@``#0```````$.``````````/0```-5
M$@``#0```````%/``````````50```0,$@``#0```````$D0````````!8P`
M7U]G;6]N7W-T87)T7U\`7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE`%])
M5$U?<F5G:7-T97)434-L;VYE5&%B;&4`7U]L:6)C7W-T87)T7VUA:6X`7U]C
M>&%?9FEN86QI>F4`7U]R96=I<W1E<E]A=&9O<FL`7U]S=&%C:U]C:&M?9F%I
M;`!?7V5N=FER;VX`<W1R;F-M<`!L<W1A=#8T`&%C8V5S<P!O<&5N9&ER`')E
M861D:7(V-`!C;&]S961I<@!R;61I<@!?7W-P<FEN=&9?8VAK`'5N;&EN:P!0
M3%]T:')?:V5Y`'!T:')E861?9V5T<W!E8VEF:6,`8F]O=%]$>6YA3&]A9&5R
M`%!E<FQ?;F5W6%,`4&5R;%]N97=84U]F;&%G<P!R96%D;&EN:P!M96UC:'(`
M4&5R;%]S=E]S971P=FX`4&5R;%]S=E]S971P=@!R96%L;&]C`&UE;6UO=F4`
M9V5T<&ED`&UE;6-P>0!S=')C:'(`<W1R9'5P`'-T<G1O:P!?7W-T<FYC<'E?
M8VAK`&=E='5I9`!S=')S='(`4&5R;%]S>7-?:6YI=#,`4&5R;%]A=&9O<FM?
M=6YL;V-K`%!E<FQ?871F;W)K7VQO8VL`4$Q?9&]?=6YD=6UP`%!E<FQ?<V%F
M97-Y<VUA;&QO8P!P97)L7W!A<G-E`'!E<FQ?9&5S=')U8W0`<&5R;%]F<F5E
M`%!E<FQ?<WES7W1E<FT`<&5R;%]A;&QO8P!P97)L7V-O;G-T<G5C=`!P97)L
M7W)U;@!E>&ET`&UK9&ER`%]?97)R;F]?;&]C871I;VX`<W1D97)R`%]?9G!R
M:6YT9E]C:&L`;W!E;C8T`&QS965K-C0`<F5A9`!C;&]S90!097)L7V=V7V9E
M=&-H<'8`4&5R;%]G971?<W8`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%]M
M9U]S970`;&EB<&5R;"YS;RXU+C,T`&QI8F,N<V\N-@!P87)?8W5R<F5N=%]E
M>&5C`'!A<E]B87-E;F%M90!84U]);G1E<FYA;'-?4$%27T)/3U0`<&%R7V5N
M=E]C;&5A;@!P87)?8W5R<F5N=%]E>&5C7W!R;V,`<&%R7V1I<FYA;64`<VAA
M7V9I;F%L`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P
M`%])3U]S=&1I;E]U<V5D`%]?9&%T85]S=&%R=`!S:&%?=7!D871E`'AS7VEN
M:70`7U]B<W-?<W1A<G0`<VAA7VEN:70`7V5N9`!P87)?;6MT;7!D:7(`7V5D
M871A`'!A<E]S971U<%]L:6)P871H`'!A<E]F:6YD<')O9P!M>5]P87)?<&P`
M<&%R7VEN:71?96YV`$=,24)#7S(N,S0`1TQ)0D-?,BXT`$=,24)#7S(N,S,`
M1TQ)0D-?,BXS+C(`1TQ)0D-?,BXS+C0`1TQ)0D-?,BXR``````````(``0`"
M``(``0`!``,``0`"``$``@`"``$``@`$``(``@`!``(``0`!``(``@`!``$`
M`@`"``(``0`%``$``@`!``(``0`!``$``@`"``(``@`!``(``@`!``$`!@`"
M``8`!0`"``<``0`"``$``@`"``$``@`&``$``@`!``<``@`"``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$````!
M``8```+G````$``````&EI&T````!P``!!D````0#6EI%`````8```0D````
M$`:6D;,````%```$+@```!`):1ER````!```!#D````0"6D9=`````,```1%
M````$`UI:1(````"```$40````````````"[L``````````,````````)!``
M``````"[N``````````,````````(\````````"_L``````````,````````
M7L````````"_Z``````````,````````P'@```````"_^``````````,````
M````(*````````#`"``````````,````````P`@```````#`&``````````,
M````````H08```````#`(``````````,````````8=@```````#`,```````
M```,````````8G@```````#`.``````````,````````8GP```````#`0```
M```````,````````H/H```````#`2``````````,````````8=X```````#`
M4``````````,````````H0(```````#`8``````````,````````H.H`````
M``#`:``````````,````````H/````````#`>``````````,````````9#H`
M``````"_D`````0````*``````````````````"_F`````<````*````````
M``````````"_H`````L````*``````````````````"_J`````X````*````
M``````````````"_N````!D````*``````````````````"_P````!X````*
M``````````````````"_R````"(````*``````````````````"_T````"0`
M```*``````````````````"_V````"@````*``````````````````"_X```
M`#L````*``````````````````"_\````$,````*``````````````````"]
MV`````(````+``````````````````"]X`````,````+````````````````
M``"]Z`````4````+``````````````````"]\`````8````+````````````
M``````"]^`````@````+``````````````````"^``````D````+````````
M``````````"^"`````H````+``````````````````"^$`````P````+````
M``````````````"^&`````T````+``````````````````"^(`````\````+
M``````````````````"^*````!`````+``````````````````"^,````!$`
M```+``````````````````"^.````!(````+``````````````````"^0```
M`!,````+``````````````````"^2````!0````+``````````````````"^
M4````!4````+``````````````````"^6````!8````+````````````````
M``"^8````!<````+``````````````````"^:````!@````+````````````
M``````"^<````!H````+``````````````````"^>````!L````+````````
M``````````"^@````!T````+``````````````````"^B````!\````+````
M``````````````"^D````"`````+``````````````````"^F````"$````+
M``````````````````"^H````",````+``````````````````"^J````"4`
M```+``````````````````"^L````"8````+``````````````````"^N```
M`"<````+``````````````````"^P````"@````+``````````````````"^
MR````"D````+``````````````````"^T````"H````+````````````````
M``"^V````"L````+``````````````````"^X````"P````+````````````
M``````"^Z````"T````+``````````````````"^\````"X````+````````
M``````````"^^````"\````+``````````````````"_`````#`````+````
M``````````````"_"````#$````+``````````````````"_$````#(````+
M``````````````````"_&````#,````+``````````````````"_(````#0`
M```+``````````````````"_*````#4````+``````````````````"_,```
M`#8````+``````````````````"_.````#<````+``````````````````"_
M0````#@````+``````````````````"_2````#D````+````````````````
M``"_4````#H````+``````````````````"_6````#P````+````````````
M``````"_8````#T````+``````````````````"_:````#X````+````````
M``````````"_<````#\````+``````````````````"_>````$`````+````
M``````````````"_@````$$````+``````````````````"_B````$(````+
M``````````#K;_`P`"2Y!``?I_O_8.,0\```),#```!2*L`0``!3&^,0$```
M!+D"`!&GA``##>'C0/$0``3K;_#0``0']`<'XQ#P.``DP!```%(1T@?P,!`(
MXQ`0$``$!_$'``<`!P#`$```4A#C$!````0'\0T0XQ`0#``4P/3____E````
M`,`0``!2!.,0$```!`?Q#1#C$!`,`!3`]/___]4````8P!```%'XXQ`0```$
M!_$-$.,0$`P`%,#T____Q0```##`$```4>SC$!````0'\0T0XQ`0#``4P/3_
M__^U````2,`0``!1X.,0$```!`?Q#1#C$!`,`!3`]/___Z4```!@P!```%'4
MXQ`0```$!_$-$.,0$`P`%,#T____E0```'C`$```4<CC$!````0'\0T0XQ`0
M#``4P/3___^%````D,`0``!1O.,0$```!`?Q#1#C$!`,`!3`]/___W4```"H
MP!```%&PXQ`0```$!_$-$.,0$`P`%,#T____90```,#`$```4:3C$!````0'
M\0T0XQ`0#``4P/3___]5````V,`0``!1F.,0$```!`?Q#1#C$!`,`!3`]/__
M_T4```#PP!```%&,XQ`0```$!_$-$.,0$`P`%,#T____-0```0C`$```48#C
M$!````0'\0T0XQ`0#``4P/3___\E```!(,`0``!1=.,0$```!`?Q#1#C$!`,
M`!3`]/___Q4```$XP!```%%HXQ`0```$!_$-$.,0$`P`%,#T____!0```5#`
M$```45SC$!````0'\0T0XQ`0#``4P/3___[U```!:,`0``!14.,0$```!`?Q
M#1#C$!`,`!3`]/___N4```&`P!```%%$XQ`0```$!_$-$.,0$`P`%,#T___^
MU0```9C`$```43CC$!````0'\0T0XQ`0#``4P/3___[%```!L,`0``!1+.,0
M$```!`?Q#1#C$!`,`!3`]/___K4```'(P!```%$@XQ`0```$!_$-$.,0$`P`
M%,#T___^I0```>#`$```413C$!````0'\0T0XQ`0#``4P/3___Z5```!^,`0
M``!1".,0$```!`?Q#1#C$!`,`!3`]/___H4```(0P!```%#\XQ`0```$!_$-
M$.,0$`P`%,#T___^=0```BC`$```4/#C$!````0'\0T0XQ`0#``4P/3___YE
M```"0,`0``!0Y.,0$```!`?Q#1#C$!`,`!3`]/___E4```)8P!```%#8XQ`0
M```$!_$-$.,0$`P`%,#T___^10```G#`$```4,SC$!````0'\0T0XQ`0#``4
MP/3___XU```"B,`0``!0P.,0$```!`?Q#1#C$!`,`!3`]/___B4```*@P!``
M`%"TXQ`0```$!_$-$.,0$`P`%,#T___^%0```KC`$```4*CC$!````0'\0T0
MXQ`0#``4P/3___X%```"T,`0``!0G.,0$```!`?Q#1#C$!`,`!3`]/___?4`
M``+HP!```%"0XQ`0```$!_$-$.,0$`P`%,#T___]Y0```P#`$```4(3C$!``
M``0'\0T0XQ`0#``4P/3___W5```#&,`0``!0>.,0$```!`?Q#1#C$!`,`!3`
M]/___<4```,PP!```%!LXQ`0```$!_$-$.,0$`P`%,#T___]M0```TC`$```
M4&#C$!````0'\0T0XQ`0#``4P/3___VE```#8,`0``!05.,0$```!`?Q#1#C
M$!`,`!3`]/___94```-XP!```%!(XQ`0```$!_$-$.,0$`P`%,#T___]A0``
M`Y#`$```4#SC$!````0'\0T0XQ`0#``4P/3___UU```#J,`0``!0,.,0$```
M!`?Q#1#C$!`,`!3`]/___64```/`P!```%`DXQ`0```$!_$-$.,0$`P`%,#T
M___]50```]C`$```4!CC$!````0'\0T0XQ`0#``4P/3___U%```#\,`0``!0
M#.,0$```!`?Q#1#C$!`,`!3`]/___34```0(P!```%``XQ`0```$!_$-$.,0
M$`P`%,#T___])0``!"#`$```3_3C$!````0'\0T0XQ`0#``4P/3___T5```$
M.,`0``!/Z.,0$```!`?Q#1#C$!`,`!3`]/___04```10P!```$_<XQ`0```$
M!_$-$.,0$`P`%,#T___\]0``!&C`$```3]#C$!````0'\0T0XQ`0#``4P/3_
M__SE```$@,`0``!/Q.,0$```!`?Q#1#C$!`,`!3`]/___-4```28P!```$^X
MXQ`0```$!_$-$.,0$`P`%,#T___\Q0``!+#`$```3ZSC$!````0'\0T0XQ`0
M#``4P/3___RU```$R,`0``!/H.,0$```!`?Q#1#C$!`,`!3`]/___*4```3@
MP!```$^4XQ`0```$!_$-$.,0$`P`%,#T___\E0``!/C`$```3XCC$!````0'
M\0T0XQ`0#``4P/3___R%```%$```````````ZV_P,``DLD\`L./P_SC_<>,P
M\*@`).-`\*``)%`@\+3KNP`@``VR3P"Q04#PH-('\,"P*$$P\*A!(/"TP.7_
M__^NQ$@``$]?Q"@``$]TN00`-,#E```@)\08``!/=)4`$`"GA`"KQ*@``$])
MXR"@```6P.7___[SN00`$N,@H```%I8"%'K`Y?___NE8H/"TE@$D>NPJ``0`
MV+D4`"+K(@`#``W`Y?___PKC,/"H``3`$```3Y2Y!`!2Q"L``$^?XR`P```$
MXQ`0```$XR!0```D6)#PM,`@```@I.,04!``).,@4`@`),`@```@G>,@4!@`
M)*>J``/LG`"?`7Y!,#`(IP@`!.Q)__\`V.,@,```!+D4`!#K$0`#``WC(5``
M`"2G"@`!ISL`"*=&__'L&0`#`-C$*```3UZY%``1ZQ$``P`-01%0`.5($```
M`+D4`$JG:0``P#````X]P.7___PN&*+L*`!#`'[$*```3T-!D/"\P.7___X"
MN00`.<`@```@!L#E```,;NPH`#D`?,0H``!/,,#E___[T<#E___]+M4'\,"P
M*+D4`"JG=`!.ZV_P^``$!_[`Y?___.#$*P``3QGL*``]`'S`Y?___5?$J```
M3I3C(*```!;`Y?___CZ2`"HGI_3_0\0H``!/`\#E___\9!BBI_3_N<`0``!/
M`N,@$````J>$``?`Y0``%VJG]/^_N00`.<`@```?D,#E```,(,0K``!.[>PH
M_[(`?*?T_^VG&``$I_3_?:<I``'`Y?___5O`Y?___;@'!T%`\`CC,/````2G
M"?_PN8``\*?[_U#7!_``\`#K[_"@`"1!</"@IVD``*=9``#`(```3FWC("``
M``3`Y?___I<```<'!P<'!P<'!P<'!P<'P!```$Z@P"```$Z=[!(`"H!DQ!@`
M`$XS[!@`!`!\!_$'_@<'!P<'!P<'!P<'!P<'P"```$Z(P!```$Z%N0D`$NLA
M``,`"NLQ`#\`#+D(`#+K,P`!``KL.``-`'S$&```3A+L&``'`'S`(```3FP'
M\0?^!P<'!P<'!P<'!P<'!P?KO_!8`"3`L```3EWC\/]@_W&5`+``IW0`%<`0
M``!-_^,0$````J>$``C$*```3@_`Y?___+3`Y?___Z62`;``Z[_P^``$!_X'
M!P<'!P<'!\#T____L`<'!P<'!P<'!P?K;_`P`"2R3P"PX_#\T/]QZ[L`(``-
MLD\`L4$0\*C2!_,HL"BY!`!!0:`@.*=9``CC,*````2G2P`0ZP,`(``,XP!/
M\/\DP#H`````XS!/^/\D0:"@"*=7_^VG20!`XS`0:``$IQL`".,P$#@`@N,P
M$`@`@N,P'_C_@NQ3(+\A6>Q3(#X!5N-0$'@`)*='_^GC`"`8``3C@/"P``3C
M`/"@`"3C0"````3C4"`0``3CH"`(``3C,/"H``3CT/"X``3"BEJ">9FY"`"`
MPCI:@GF9PMI:@GF9XS`@(``(N0@`U>MJ``(`#.QJ`"$>5NR6(+\`5;GGD!6Y
M@``4N8(`%;D(`!BYYP"%N8``BKF"`(#L=""_)5GL="`Z!5:Y"`!SZS0``@`,
MN0@`>.PT`"$>5NR'(+\`5;F"`&.Y@`!HN8(`:;D(`&WCT/#```3L=SN_)5G"
MVEJ">9GL>``Z!5:YZ)`-N0@`%^N8``(`#.QQ(+\`5>R8`"$>5NP1.[\E6>P7
M`#H%5KD(`!;L8R"_`%7LT3N_)5FY@@`Y[($@OP!5N>1P$[D$`#WCT/#(``3L
M.``Z!5;"VEJ">9FY@@`6N0@`$+GH8`VY"``3[&D@OP!5[-$[OR59ZS<``@`,
M[#<`(1Y6N8(`D^QQ(+\`5;GD@!FY!`"=X]#PT``$[)<`.@56PMI:@GF9N8(`
M%KD(`!"YZ&`-N0@`&>QC(+\`5>S1.[\E6>N8``(`#.R8`"$>5KF"`#GL@2"_
M`%6YY'`3N00`/>/0\-@`!.PX`#H%5L+:6H)YF;F"`!:Y"``0N>A@#;D(`!/L
M:2"_`%7LT3N_)5GK-P`"``SL-P`A'E:Y@@"3['$@OP!5N>2`&;D$`)WCT/#@
M``3LEP`Z!5;"VEJ">9FY@@`6N0@`$+GH8`VY"``9[&,@OP!5[-$[OR59ZY@`
M`@`,[)@`(1Y6N8(`.>R!(+\`5;GD<!.Y!``]X]#PZ``$[#@`.@56PMI:@GF9
MN8(`%KD(`!"YZ&`-N0@`$^QI(+\`5>S1.[\E6>LW``(`#.PW`"$>5KF"`)/L
M<2"_`%6YY(`9N00`G>/0\/``!.R7`#H%5L+:6H)YF;F"`!:Y"``0N>A@#;D(
M`!GL8R"_`%7LT3N_)5GKF``"``SLF``A'E:Y@@`Y[($@OP!5N>1P$[D$`#WC
MT/#X``3L.``Z!5;"VEJ">9FY@@`6N0@`$+GH8`VY"``3[&D@OP!5[-$[OR59
MZS<``@`,[#<`(1Y6N8(`D^QQ(+\`5;GD@!FY!`"=X]#Q```$[)<`.@56PMI:
M@GF9N8(`%KD(`!"YZ&`-N0@`&>QC(+\`5>S1.[\E6>N8``(`#.R8`"$>5KF"
M`#GL@2"_`%6YY'`3N00`/>/0\0@`!.PX`#H%5L+:6H)YF;F"`!:Y"``0N>A@
M#;D(`!/L:2"_`%7LT3N_)5GK-P`"``SL-P`A'E:Y@@"3['$@OP!5N>2`&;D$
M`)WCT/$0``3LEP`Z!5;"VEJ">9FY@@`6N0@`$+GH8`VY"``9[&,@OP!5[-$[
MOR59ZY@``@`,[)@`(1Y6N8(`.>R!(+\`5;GD<!.Y!``]X]#Q&``$[#@`.@56
MPMI:@GF9N8(`%KD(`!"YZ&`-N0@`$^QI(+\`5>S1.[\E6>LW``(`#.PW`"$>
M5KF"`)/L<2"_`%6YY(`9N00`G>/0\2``!.R7`#H%5L+:6H)YF;F"`!:Y"``0
MN>A@#;D(`!GL8R"_`%7LT3N_)5GKF``"``SLF``A'E:Y@@`Y[($@OP!5N>1P
M$[D$`#WCT/$H``3L.``Z!5;"VEJ">9FY@@`6N0@`$+GH8`VY"``3[&D@OP!5
M[-$[OR59ZS<``@`,[#<`(1Y6N8(`D^QQ(+\`5;GD@!FY!`"=X]#Q,``$[)<`
M.@56PMI:@GF9N8(`%KD(`!"YZ&`-N0@`&>QC(+\`5>S1.[\E6>N8``(`#.R8
M`"$>5KF"`#GL@2"_`%6YY'`3N00`/>/0\3@`!.PX`#H%5KF"`!:Y"``0N0@`
M$^LW``(`#.PW`"$>5N-P\4``!,+:6H)YF;GH8`WL:2"_`%7">EJ">9FY@@"3
MN8``F+F"`):Y"`"0N>A@!^MH``(`#.QH`"$>5N.`\4@`!.QS(+\`5<**;MGK
MH;F"`#;LT3N_)5GLT2`Z!5;`&@````"Y@``QN8(`-[D(`##C`/%0``2Y"`"=
MN0@`>.S9.[\E6>N!``(`#.S9(#H%5NR!`"$>5KD(`#WL$SN_)5GL$R`Z!5:Y
MYX#6P@INV>NAN8(`V;D:``:Y&@!]N0@`<>P7.[\E6>P7(#H%5K/!`"'LV2*_
M/EGC$/%8``3LV0(A'E:Y!`"0N>?0:+/-``*Y@@!CN1H`ENQC(K\^6>QC`B$>
M5KGG8#VY@@`WN0@`D,(:;MGKH;D:`!CLB3N_)5FY&@`3[(D@.@56L\$`"+/-
M`##C@/%@``2Y"``3[#$[OR59[#$@.@56L\$``^,P\6@`!+/-``#"BF[9ZZ'"
M.F[9ZZ&Y&@"-N1H`-NS7(K\^6>S7`B$>5KGGT':Y@@!YN1H`A[D(`(#L:#N_
M)5GL:"`Z!5;L>2*_/EFSP0`&['D"(1Y6[&$BOSY9N>=PG>QA`B$>5KF"`)&S
MS0`0N1H`.>.0\7``!+D(`#'"FF[9ZZ&YYV`7N8(`&+D:`)VY&@"1XQ#Q>``$
M[-,[OR59[-,@.@56PAINV>NAN0@`G;D:`!?LV3N_)5GL>"*_/EGLV2`Z!5;L
M>`(A'E:SP0`-XX#Q@``$L\T``+GG<-;"BF[9ZZ&Y@@#3N1H`AKD:`!WL8R*_
M/EFY"``0[&,"(1Y6[#$[OR59[#$@.@56L\$``^,P\8@`!+/-``"YYV#7N8(`
MV<(Z;MGKH;D:`(VY&@`WN0@`@.QY(K\^6>S8.[\E6>QY`B$>5NS8(#H%5N.0
M\9``!+/!``VSS0``N>=PUL*:;MGKH;F"`-&Y&@"6N1H`/>QA(K\^6;D(`##L
M80(A'E;L$SN_)5GL$R`Z!5:SP0`!XQ#QF``$L\T``+GG8->Y@@#8PAINV>NA
MN1H`G;D:`!>Y"`"0['@BOSY9[-D[OR59['@"(1Y6[-D@.@56XX#QH``$L\$`
M#;/-``"YYW#6PHINV>NAN8(`T[D:`(:Y&@`=[&,BOSY9N0@`$.QC`B$>5NPQ
M.[\E6>PQ(#H%5K/!``.SS0``N>=@U^,P\:@`!+F"`-FY&@"-N0@`@.S8.[\E
M6>S8(#H%5K/!``VSS0``PCINV>NAN1H`-^QY(K\^6>QY`B$>5N.0\;``!+GG
M<-:Y@@#1N1H`/>S1(K\^6;D(`##LT0(A'E;L$SN_)5GL$R`Z!5:SP0`!XQ#Q
MN``$L\T``,*:;MGKH;D:`):YY]!GN8(`:+D:`):Y"`"0[&D[OR59[&D@.@56
ML\$`!N-@\<``!+/-``#"&F[9ZZ'":F[9ZZ&Y&@`7N1H`;>QX(K\^6>QX`B$>
M5KGG<(WLTR*_/EFY@@"#[-,"(1Y6N1H`&+D(`!#L,3N_)5GL,2`Z!5:SP0`#
MXS#QR``$L\T``+GGT(?".F[9ZZ&Y@@")N1H`-[D:`&BY"`!@['8[OR59['8@
M.@56L\$`![/-``#LB2*_/EGC</'0``3LB0(A'E:YYX"=N8(`D;D:`#GLD2*_
M/EFY"``P[)$"(1Y6[!,[OR59[!,@.@56PGINV>NAL\$``;D:`'WC$/'8``2Y
MYY#8N8(`UK/-``"Y&@!][-8BOSY9[-8"(1Y6N>?0:;F"`&/"&F[9ZZ&Y&@`8
MN1H`%NQC(K\^6>QC`B$>5N,P\>``!+D(`'#LAR"_`%7L!SN_)5GL"``Z!5;"
M.F[9ZZ&Y"``0N1H`.;GG8`VY@@`'N1H`,+D$`)/C,/'H``3L<2"_`%7L$3N_
M)5GL%P`Z!5;".H\;O-RY"`"1N1H`/>L8``(`#+/!``/L&``A'E:SS0``[-$@
MOP!5N>30AKGF$#:Y@``WN8$`..R)(+\`5>R9.[\E6>R8`#H%5KD(`##C`/'P
M``2Y"``YZY<``@`,[)<`(1Y6N>30>;F!`!FY@``8N8$`%^-P\?@`!,(*CQN\
MW+D:``;">H\;O-RY"``0N>C0!^QC(+\`5>PS.[\E6>PV`#H%5KD(`#'K&``"
M``SL&``A'E;LT2"_`%6YYA!YN>30B;F``':Y@0!XN0@`<.,`\@``!.R#(+\`
M5<(*CQN\W+D:``GKE@`"``SLE@`A'E:YY-!IN8$`&;F``!BY@0`6XV#R"``$
MN0@`$,)JCQN\W+GHT`;L,SN_)5GL.``Z!5:Y"``W[',@OP!5[#,[OR59[#<`
M.@56N0@`,>L8``(`#.P8`"$>5NS1(+\`5;GF$&FYY-")N8``9[F!`&BY"`!@
MXP#R$``$[(,@OP!5P@J/&[S<N1H`">N7``(`#.R7`"$>5KGDT'FY@0`9N8``
M&+F!`!?C</(8``2Y"``0PGJ/&[S<[#,[OR59N>C0!^PX`#H%5KD(`#;L8R"_
M`%7L,SN_)5GL-@`Z!5:Y"``QZQ@``@`,[!@`(1Y6[-$@OP!5N>80B;GDT'FY
M@`"&N8$`A[D(`(#L<R"_`%7C`/(@``3L,SN_)5GL-P`Z!5:Y"``XZX8``@`,
M[(8`(1Y6N>30:+F!`!BY@``7N8$`%N-@\B@`!,(*CQN\W+D:``G":H\;O-RY
M"``0N>C0!NR3(+\`5>PS.[\E6>PY`#H%5KD(`#'K%P`"``SL%P`A'E;LT2"_
M`%6YYA!HN>30>+F``&FY@0!GN0@`8.,`\C``!.QS(+\`5<(*CQN\W+D:``CK
MB0`"``SLB0`A'E:YYH"1N>30&+F``)>Y@0"1XQ#R.``$N0@`D,(:CQN\W+D(
M`!VSP0`!L\T``.PS.[\E6>PW`#H%5KD(`#;L8R"_`%7L,SN_)5GL-@`Z!5;K
M%P`"``RY"`"3[!<`(1Y6[-$@OP!5N>80.+GDT'BY@``VN8$`-[D(`##C`/)`
M``3L>2"_`%7""H\;O-SLF3N_)5FSP0``[)<`.@56N0@`.>N6``(`#.R6`"$>
M5KGDT`FSP0`@L\T``+F!`!FY&@`(L\$``+/-``*Y@``7N8$`$+/-``#L8R"_
M`%7C@/)(``2Y"``0PHJ/&[S<N>C0".PS.[\E6>PV`#H%5KD(`#'K%P`"``SL
M%P`A'E;LT2"_`%6YYA!YN>30B;F``':Y@0!XN0@`<.,`\E``!.R#(+\`5>PS
M.[\E6>PX`#H%5L(*CQN\W+D:``FYZ#"7ZS8``@`,[#8`(1Y6N>308[F!`!.Y
M@``8N8$`%N-@\E@`!+D(`!#":H\;O-RYZ-`&['D@OP!5[)D[OR59[)<`.@56
MN0@`D>L8``(`#.P8`"$>5NS1(+\`5;GF$&.YY-"#N8``9[F!`&BY"`!@XP#R
M8``$[(D@OP!5[)D[OR59[)@`.@56P@J/&[S<N1H``[GHD#;KEP`"``SLEP`A
M'E:YY-!YN8$`&;F``!BY@0`7XW#R:``$N0@`$,)ZCQN\W+GHT`?L8R"_`%7L
M,SN_)5GL-@`Z!5:Y"``QZQ@``@`,[!@`(1Y6['$@OP!5N>80V;GD<(FY@`#6
MN8$`V+D(`-#C`/)P``3L@R"_`%7""H\;O-SL,SN_)5FY&@`)L\$``.PX`#H%
M5KD(`#WKE@`"``SLTR"_`%7LE@`A'E;L8SN_)5FYYI`QN>1P&;/!`"&SS0`"
MN00`%N-@\G@`!+F``#BY@0`PL\T``.P=`#H%5L)JCQN\W+D(`#"YZ'`&N0@`
M,>L8``(`#.P8`"$>5NQQ(+\`5;GD<&FYYA")N8``C;F!`(;L8SN_)5GL8R`Z
M!5:Y"`"`N0@`AN-@\H``!.L-``(`#,)JCQN\W+D:`&FY!`"0L\$`!NR=`"$>
M5KGD<&G`.@````"SS0``N8$`&;F``!.Y@0`6XV#RB``$N0@`$,)JRF+!UNS8
M.[\E6;GH<`;LV"`Z!5;K<P`"``RY"``=[',`(1Y6[&$[OR59N00`,.QA(#H%
M5N/0\I``!+/!`$:SS0`$N>=P:;F"`&C"VLIBP=:Y&@`VN1H`V;D(`#"SP0!M
M[&@BOSY9XP#RF``$[&@"(1Y6L\T`ANR3.[\E6>R3(#H%5KGG8-?""LIBP=:Y
M@@#1N1H`![D:`(VY"`")[)@[OR59[)@@.@56['$BOSY9L\$`*>QQ`B$>5N.0
M\J``!+D$`!"SS0`"N>=PUL*:RF+!UKF"`-.Y&@"6N1H`'>QC(K\^6;D(`!#L
M8P(A'E;L,3N_)5GL,2`Z!5:SP0`#XS#RJ``$L\T``+GG8->Y@@#8PCK*8L'6
MN1H`G;D:`#>Y"`"0['@BOSY9[-D[OR59['@"(1Y6[-D@.@56XX#RL``$L\$`
M#;/-``"YYW#6PHK*8L'6N8(`T;D:`(:Y&@`][&$BOSY9N0@`,.QA`B$>5NP3
M.[\E6>P3(#H%5K/!``'C$/*X``2SS0``N>=@U[F"`-G"&LIBP=:Y&@"-N1H`
M%[D(`(#L>2*_/EGLV#N_)5GL>0(A'E;LV"`Z!5;CD/+```2SP0`-L\T``+GG
M<-;"FLIBP=:Y@@#3N1H`EKD:`!WL8R*_/EFY"``0[&,"(1Y6[#$[OR59[#$@
M.@56L\$``^,P\L@`!+/-``"YYV#7N8(`V,(ZRF+!UKD:`)VY&@`WN0@`D.QX
M(K\^6>S9.[\E6>QX`B$>5NS9(#H%5N.`\M``!+/!``VSS0``N>=PUL**RF+!
MUKF"`-&Y&@"&N1H`/>QA(K\^6;D(`##L80(A'E;L$SN_)5GL$R`Z!5:SP0`!
MXQ#RV``$L\T``+GG8->Y@@#9PAK*8L'6N1H`C;D:`!>Y"`"`['DBOSY9[-@[
MOR59['D"(1Y6[-@@.@56XY#RX``$L\$`#;/-``"YYW#6PIK*8L'6N8(`T[D:
M`):Y&@`=[&,BOSY9N0@`$.QC`B$>5NPQ.[\E6>PQ(#H%5K/!``/C,/+H``2S
MS0``N>=@U[F"`-C".LIBP=:Y&@"=N1H`-[D(`)#L>"*_/EGLV3N_)5GL>`(A
M'E;LV2`Z!5;C@/+P``2SP0`-L\T``+GG<-;"BLIBP=:Y@@#1N1H`AKD:`#WL
M82*_/EFY"``P[&$"(1Y6[!,[OR59[!,@.@56L\$``>,0\O@`!+/-``"YYV#7
MN8(`V<(:RF+!UKD:`(VY&@`7N0@`@.QY(K\^6>S8.[\E6>QY`B$>5NS8(#H%
M5N.0\P``!+/!``VSS0``N>=PUL*:RF+!UKF"`-.Y&@"6N1H`'>QC(K\^6;D(
M`!#L8P(A'E;L,3N_)5GL,2`Z!5:SP0`#XS#S"``$L\T``+GG8-?".LIBP=:Y
M@@#8N1H`-[D:`)VY"`"0['D[OR59['D@.@56L\$`!^-P\Q``!+/-``#LV"*_
M/EG">LIBP=;LV`(A'E:Y&@!VN>?0ANQA(K\^6;F"`('L80(A'E:Y&@`XN0@`
M,.P3.[\E6>P3(#H%5KGG8(VSP0`!N8(`B>,0\Q@`!+D:`'CLB2*_/EGLB0(A
M'E:YYX"6N8(`D[/-``#"&LIBP=:Y&@`=N1H`&>R3(K\^6>R3`B$>5N,P\R``
M!+D(`'#".LIBP=;LUR"_`%6Y"``T[`<[OR59N1H`-NP-`#H%5KD(`!"YYY`(
MN00`0+F"`$>Y!`!S[#$@OP!5N1H`=.P1.[\E6>P3`#H%5KD(`!>Y"``ZP#H`
M````XS`@"``DP!H`````XQ`@```DXS#PH``$N00`&.,0("``",`:`````.,0
M("``)+D(`#GK'0`"``S`.@````#C,"`8`"3L'0`A'E:Y"``5P!H`````XQ`@
M$``DU0?S*+`HIW0`!NMO\V``!`?^P.7___&P!P?K;_`P`"3C\/]@_W'L*`!<
M`'S$&```0C_C<!````*GA`!3XQ`@``"4N00`@KD$`&.Y!`"2E0`@`*>$`$[L
M&``,/7Y!D)`!XQ"0``"4E0"0`*=T__8;F..@<````J>$`!^Y%`"9N00`M[D$
M`$FY!``XN00`*L#E___P0NPF``D`?D$9H`"5/1``IX0`#T&PL`CCH+````*G
M=/_IN00`*NMO\-``!`?^N>EP&T&IH`'K$0`#``I0$&``N00`*NMO\-``!`?^
MIZD``+D$`"KK;_#0``0'_J>8``"G]/^_!P<'!^NO\%``)+)/`+#C\/[(_W'K
MNP`@``VR3P"QN00`HM('\3"P*$$P\*#`Y?__\5CL)@`A`'X8$E@@\+BG.$``
MP"L``/``[",`"(!VI3^@`.PC`!-@=KD$`"JG.0`"P.7___&^$!*G&O__B!``
M'Z?T``2G&```U0?Q,+`HN10`(:=T``;KK_&(``0'_L#E___P]^MO\#``)+)/
M`*#C\/[`_W'KJ@`@``VR3P"AT@?Q.*`H["@`"0!\N00`8I4`(`"G=``+U0?Q
M.*`HIW0`B.MO\7``!`?^P.7___&RN00`LNPH__(`?.R&/+\`54'0\*BG>0`/
MN00`*\#E___P,>PH`%0`?$&0(!.5+B`3IW0`!I4`D`&GA/_PE2X@$Z>$`%&G
M&0``[(@`5P!\N>F`-^<#8```-Z<;`!#G```P`(&GA``,YP%@`$`&IQL`$.<`
M`#``@:=T__CG0``'`"&YA`!$N2``0T$P,`&YXB`3IR0`,^-!3_#_<:<Y``#L
M&3R_`%6GA``PN>D0%^<!(!,`-Z<[`!#G```P`(&GA``HYP,@$T`&I_3_]KD$
M`"O`Y?__[GBY!``FP.7__^[3I_3_A94ND`&G=/^OE0"0`J>$_Y6G]/^IISD`
M#Z?T_[;`Y?__\%"G&0`/I_3_W.=0``<`(;F$`%6Y(`!101`0`;GB(#&G)/_Q
MXQ-?\/]QN?@0)*<J``*Y%``BP.7__^YSXY#PH``DISD``;D$`)+`4```$;VG
M2?__P.7___#DN00`/;D$`"G`Y?__[RWL*``-_WY8$/#`IRA``,`;``#P`.P2
M``^`=KD$`"G`Y?__\$NY!``IP.7___"6I_3_0+D$`"G`Y?___PNG]/_T!P<'
M!P<'!P<'!P<'ZV_P,``DQ+@``$"1X_#_6/]QXR"P```6P&```!+8P.7___`U
MXR"P```6P.7___`OQ$@``$"4P%```#$SP#```!%MP.7___"CXR"P```6P.7_
M__`=P$````_^Y4CPH```N00`5L`P```19\#E___O#^MO\-@`!`?^!P<'!P<'
M!P?K?_`X`"3C\/``_W'C`/_X`"#C\/]8_W'C`/"@`""R3P"`XQ#PH`%QZX@`
M(``-LD\`@;D$`*/2!Q``@"A!D/"@N00`LKD$`#FG20__P"```!$^P.7__^Y[
M["P`,0!^[!+__P#8N10`<4$W\*"5`#``IW0`0>P8`",`?KD$`$>Y!``IISD`
M+\#E___N<>PH`!<`?,08``!`"^,@$```%L#E___OM;D$`%>Y!`!)N00`.\#E
M___O#*?T`!+$&```/_?C(!```!;`Y?__[Z&Y!`!*N00`.\#E___M^N,0\*`!
M<=4'$`"`**=T``KK?_#@`00'_KD4`'*G]/_"P.7__^\WZV_P,``DN00`[[)/
M`(#C\/]`_W&GZ__X8(#@`.N(`"``#;)/`(&Y!`"RN00`HY4],`#2!_"P@"BG
M=``$0:`P`:<9``#L.CR_`%6GA`!YIRD`#[D)`"/G`J```#>G&P`0YP``,`"!
MIX0`#.<!H`!`!J<;`!#G```P`(&G=/_XYS``!P`AN80`,[D@`#)!("`!N>(@
M$J<D`%3C$3_P_W%!,/"LXQ#PH``DN00`*\#E___],KD$`#+L*`!+`'RG&0``
M[$(\OP!5IX0`/Z<I``^Y"0`DYP(P```WIQL`$.<``#``@:>$``SG`3``0`:G
M&P`0YP``,`"!IW3_^.=```<`(;F$`$2Y(`!"02`@`;GB(!*G)``:XR#PH``$
MXQ%/\/]Q["$!!,!EXY#PK``4Q'@``#\ZZYD``P`-I_0`5Z<I``^G]/^5IRD`
M#Z?T_\_$>```/RKCD'````3C$)````*GA`#<N00`&:=H```8)J=J``%!$!`(
MXS`0```"IW3_^*<J``.Y%``BZR(``P`-P!```#^&XQ`0```2IX0`FKD$`#*Y
M!``IP.7__^V2XR!P```DL\$`@NPH`'T`?+D4`);KF0`#``VSS0`84&#PK.S6
M``$`V+D4`-WKW0`#``U!'1``Y4@0````XR"P``"4N00`&Y4`L`"G=``-I_0`
MBT$0$`'C(!```)25`!``IX0`!>PF__<]?KD)`!NY%``1XR#PH``$N00`:4$B
M$`+C8'````C`Y?__[%SC(&```"3L*``Y`'SC('````3C$+```)#C.2````1!
ML+`!0A`P`!A![!8`$`!\I_0`,.,0L```D$&PL`%"$"`!&$'L&``F`'Q"0/"@
MN00`(Y4]\*!!,#`!IW3_[9(](`"G&0``XS&@``"00C$@`:<;``'L-O_Y`'S5
M!_"P@"BG=``W:(#PN.MO\/``!`?^N00`(Z?T_^7`$```/N;E3!````'`Y?__
M[`BY!`#2L\$`@NPH_^0`?+D$`#FY%`"6ZYD``P`-N00`2<#E___L=>/0<```
M)*?T_UVG&0``I_3_A:<I`!"G:```I_3_-\#E___MHZ<9``#C(:```)!"(3``
MIQL``>PF__D`?*?T_[<'!P<'!P<'!P<'!P?K[_!P`"3$&```/BGC\/]@_W'C
M(!```!;`Y?__[=#$2```/C7`4```+M3`,```#P[K[_$0``3`]/__[D$'!P<'
MZV_P,``DX_#P`/]QXP#_^``@X_#P`/]QXP#_^``@X_#_2/]QXP#PL``@LD\`
MD.,0\+`"<>N9`"``#;)/`)'CL/"O`7'2!Q``D"C`Y?__[1?`$```#P+C$/"@
M`"2Y!`!BITD0`:<Y``&Y!``KP%````[N08#PKL#E___M\;D$`"NY!``XITD0
M`,#E___L&.PD`"P`?KD$`+*G*@`!N10`(L#E___K7+D$`*+L*``0`'RY%`"[
MN00`.+D$`$O`Y?__[AY!&Z``D@`0`.,0\+`"<=4'$`"0**=T``RY!``JZV_P
MZ`($!_ZGJ0``I_3_\,#E___L]0<'!P<'!P<'!P<'!\#T____@`<'!P<'!P<'
M!P?K;_`P`"3C\/``_W'C`/_X`"#C\/ZP_W'C`/%(`""R3P"0XQ#Q2`%QZYD`
M(``-LD\`D;D$`(+2!Q``D"BY!`"CP"````Z%03#PM,#E___[$Z<Y`"^Y!`"R
MN00`*,#E___LQNPH`!D`?,`@```.=KD$`#C`Y?___7>Y!``HXQ#Q2`%QU0<0
M`)`HIW0!&.MO\8`!!`?^IQD``.PX/+\`5:>$`)RG*0`/N0D`(^<"@```-Z<;
M`!#G```P`(&GA``,YP&``$`&IQL`$.<``#``@:=T__CG,``'`"&YA``SN2``
M,D$@(`&YXB`2IR0`=[D$`"KCH3_P_W'`Y?__ZZG`,```#C/`Y?__ZO.Y!`!B
M["C_K@!\IZH``4%P\4A!T/"XE0!@`*>$`'/LN``/`'RG"```N00`%KD$`"NR
M70`2IQ3__J>$`%.G&0``[#8\OP!5IX0`L:<I``^Y"0`CYP)@```WIQL`$.<`
M`#``@:>$``SG`6``0`:G&P`0YP``,`"!IW3_^.<P``<`(;F$`#.Y(``R02`@
M`;GB(!*G)`",XT$_\/]QN00`-NP4__\`V+D8`#&5+S``IW0`-I(`,``80;D$
M`#:G&O__N1@`,94O,`"GA/_UI_0`)Z<I``^G]/]RE0"P`:=T`!K`,```#;ZG
M*0``P.7__^I\N00`8NPH_S<`?)4`8`"G=/^1[+@`!P!\E2ZP`*>$_^;`8```
M#9FG2``!&DJG&`__[$'_(2!VXX#PJ``DP!````V9XQ#PH``DISD``;D$`"?`
M4```#@"G21``P.7__^Q\N00`/;D$`"?`Y?__ZL7L)O_!`'Y8$/#0I2^``,`;
M``#P`.P2_[=@=KD$`">G.0`!P.7__^Q1[";_K0!^N00`-\`@```-7\#E___\
M8KD$`"?`Y?__ZM&G]/[HIRD`#Z?T_UW`Y?__ZX@'!Y4`(`"Y!``2XS`@``"4
M!XZG/@`O01`0`;GB@"'C,!```)25`!``!XZG/@`O01`0`;GB@"'C,!```)25
M`!``IW3_Z0?^!P<'!P<'!P<'!P<'["@`5@!\N00`,I4`(`"GA`!/IQD``.Q"
M/+\`5:>$`$2G*0`/N0D`).<",```-Z<;`!#G```P`(&GA``,YP$P`$`&IQL`
M$.<``#``@:=T__CG0``'`"&YA`!$N2``0D$@(`&YXB`2IR0`'^,13^__<;D(
M`!.YZ3!![#$`=J!EE2\0`*=T`!OC$!___W&G1__YE2\P`*>$``S`(```#-[`
M]/__ZDVG*0`/I_3_RL`@```,QL#T___J0^PQ`%:@9;GI,$'C$!___W&G1P`$
MI_3_XI4O$`"G=/_WN>DP0>,@'___<>PR`"P@9>PX`"G_?.,0'___<:='`">Y
M"0`3ITD0`.PA``(`V>PD`"P@9>OO\'``)$%`$`'C\/]@_W&G61``P"```#OT
MP.7__^BYP"```#ONZ^_Q$``$!_ZG20`!I_3_V)4O$`"GA/_4N0D`$Z=)$`#L
M(0`"`-GL)/_:P&6G*0``!_[L,?^Z8&2G]/^3!P?KK_!0`"2R3P"PX_#_4/]Q
MZ[L`(``-LD\`L4&@\*32!_"HL"BY!``ZP"````Q?P.7___CA["@`+@!\Q"@`
M`#LCXQ#PI``4ZQ$``P`-XQ`@```(XR`0"``$XR`0```D["C_XP!\XR`0$``$
M01`0".,@$```).PF__@`?+D$`#K`(```##3`Y?__^+;L)O_8`'RY!``ZP"``
M``PNP.7___BK["@`+@!\Q"@``#KMXQ#PI``4ZQ$``P`-XQ`@```(XR`0"``$
MXR`0```D["C_XP!\XR`0$``$01`0".,@$```).PF__@`?+D$`#K`(```#`/`
MY?__^(#L)O_8`'RY!``ZP"````O\P.7___AU["@`+@!\Q"@``#JWXQ#PI``4
MZQ$``P`-XQ`@```(XR`0"``$XR`0```D["C_XP!\XR`0$``$01`0".,@$```
M).PF__@`?+D$`#K`(```"]'`Y?__^$KL)O_8`'RY!``ZP"````O+P.7___@_
M["@`+@!\Q"@``#J!XQ#PI``4ZQ$``P`-XQ`@```(XR`0"``$XR`0```D["C_
MXP!\XR`0$``$01`0".,@$```).PF__@`?+D$`#K`(```"Z#`Y?__^!3L)O_8
M`'RY!``ZP"````N9P.7___@)["@`+@!\Q"@``#I+XQ#PI``4ZQ$``P`-XQ`@
M```(XR`0"``$XR`0```D["C_XP!\XR`0$``$01`0".,@$```).PF__@`?+D$
M`#K`(```"V[`Y?__]][L)O_8`'RY!``ZP"````MKP.7___?3["@`+@!\Q"@`
M`#H5XQ#PI``4ZQ$``P`-XQ`@```(XR`0"``$XR`0```D["C_XP!\XR`0$``$
M01`0".,@$```).PF__@`?+D$`#K`(```"T#`Y?__]ZCL)O_8`'RY!``ZP"``
M``L-P.7___>=["@`+@!\Q"@``#G?XQ#PI``4ZQ$``P`-XQ`@```(XR`0"``$
MXR`0```D["C_XP!\XR`0$``$01`0".,@$```).PF__@`?+D$`#K`(```"N+`
MY?__]W+L)O_8`'RY!``ZP"````L%P.7___=G["@`+@!\Q"@``#FIXQ#PI``4
MZQ$``P`-XQ`@```(XR`0"``$XR`0```D["C_XP!\XR`0$``$01`0".,@$```
M).PF__@`?+D$`#K`(```"MK`Y?__]SSL)O_8`'RY!``ZP"````K4P.7___<Q
M["@`+@!\Q"@``#ESXQ#PI``4ZQ$``P`-XQ`@```(XR`0"``$XR`0```D["C_
MXP!\XR`0$``$01`0".,@$```).PF__@`?+D$`#K`(```"JG`Y?__]P;L)O_8
M`'RY!``ZP"````JCP.7___;[["@`+@!\Q"@``#D]XQ#PI``4ZQ$``P`-XQ`@
M```(XR`0"``$XR`0```D["C_XP!\XR`0$``$01`0".,@$```).PF__@`?+D$
M`#K`(```"GC`Y?__]M#L)O_8`'RY!``ZP"````HZP.7___;%["@`+@!\Q"@`
M`#D'XQ#PI``4ZQ$``P`-XQ`@```(XR`0"``$XR`0```D["C_XP!\XR`0$``$
M01`0".,@$```).PF__@`?+D$`#K`(```"@_`Y?__]IKL)O_8`'RY!``ZP"``
M``H\P.7___:/N00`,NPH``D`?,`@```*)\#E___X_+D$`#K`(```"C+`Y?__
M]GRY!``R["@`"0!\P"````HPP.7___CIN00`.L`@```*+L#E___V:;D$`#+L
M*``:`'S`(```"<[`Y?__^-;5!_"HL"BG=``CP#````HIP"````G@ZZ_Q```$
MP/3___C%N00`.L`@```*$L#E___V1;D$`#+L*/_E`'S`(```"=C`Y?__^+*G
M]/_<P.7__^?A!P<'!^N_\%@`)+)/`+#C\/]0_W'KNP`@``VR3P"QQ"T``#BK
MT@?PJ+`H["@`#O]^U0?PJ+`HN10`(J=T`"CKO_$(``0'_D$P\*3`(```":C`
MY?__]@KL*``6`'R_$2``IX0`$<`7````,+F$`!&Y`P`A["(_OP%9Q"\``#A^
MI_3_V:<H``"G]/_YP.7__^>9!P<'!^OO\'``)./P_V#_<<#E___E7L#E___E
M.^PH``8`?.,@(```!.OO\1``!`?^!P<'!^MO\#``)+)/`*#C\/]`_W'KJ@`@
M``VR3P"AN00`8M('\+B@*$$P\+3`(```"9#`Y?__];GL*``:`'RY!`"RE0`@
M`*>$`!.Y!``VP.7__^6'["@`'`!\U0?PN*`HIW0`8^MO\/``!`?^U0?PN*`H
MIW0`6KD$`#;`(```"6GK;_#P``3`]/__^`>G&0``[#8\OP!5IX0`1*<I``^Y
M"0`CYP)@```WIQL`$.<``#``@:>$``SG`6``0`:G&P`0YP``,`"!IW3_^.<P
M``<`(;F$`#.Y(``R02`@`;GB(!*G)``?XT$_\/]QIRD``.P[/+\`5:>$`!RG
M&0`/N0D`$^<!L```-Z<K`!#G```P`(&GA``2YP*P`$`&I_3_]J<I``^G]/_*
MP.7__^;KIQD`#Z?T__+G,``'`"&YA``SN2``,4$0$`&YXB`AIR3_\>,2/_#_
M<4$D$`+`Y?__Y1+CL/"H`"3`$```")GC$/"@`"2Y!`"RP%````D#ITG__Z<Y
M``'`Y?__YWW5!_"XH"BG=/_,N00`.\`@```(V^MO\/``!,#T___W>0<'!P<'
M!P<'!P<'!^OO\'``)*<I`(#C\/]@_W'`Y?__Y-S`,6=%(P'C,"```"3`/^_-
MJXGC,"`(`"3`/YBZW/[C,"`0`"3`,1`R5';C,"`8`"3E2"`H``#E2"`P``#E
M3"!X``#`/\/2X?#C,"`@`"3K[_$0``0'_@<'!P?KG_!(`"2R3P"0X_#_4/]Q
MZYD`(``-LD\`D;D$`*+2!_"HD"C`Y?__^O[C$"```)2Y!`"RE0`@`*>$``^G
M'@`O02`@`;GB@++C$"```)25`"``IW3_]<0=```W'>P8`!;_?NP8``H`?NRH
M``<`?)4`H`"G=``GU0?PJ)`HIW0`1.N?\/@`!`?^03#PI,`@```(%<#E___T
M=^PH`"X`?.,0(```E.P8`"@`?NP8`"4P?L`0```V\.5,$````:?T_]:Y!``K
MITD`!,`P```(.,#E___DU>PF_]$`?M4'\*B0**=T`!*Y!``JZY_P^``$P/3_
M__4!P!```#;.Y4P0````I_3_N\#E___EZ@<'!P<'!^MO\#``)+D$`)+C("`H
M``3K%``#``VY"``2[%$@OP!5N00`A./P_V#_<>-`D#``!+D$`+.Y,0`AI\0`
M!*=+``'C4)`H`"3K&``=``RY"``4XQ"0,``D07"0..,0D'@`$J=T`#SLC`!B
M/W[L:/_``-B(8``&[!8``0#8[!$?N099[*'_P`#90=&P`.NJ``8`#*>K``'2
M/W``L`"Y!``I0;"P0,#E___H=Z>G__:GBO_`B6``!AN&N10`B+D$`#VY!``G
MN00`2,#E___FD5"`D'CK;_#0``0'_J>H`$`;H1FHN00`)[GR,*BY&``AN10`
M:KD$`#NY!`!&P.7__^9X&!I:$)!X4!"0>.P6_^1`?KGYH*BY!``IN0@`MKD4
M`(K`Y?__Z#FG]/^@N00`VZ?T_\?KC_!``"3CD#`H``2Y!`"SXX`P,``$[#DZ
MOSU9N10`$T$1L#B2@!``ISH``>/P_V#_<;D4`!.Y!`"B01&P..P\`%TX?J=(
M`$"Y^3`D[$,`$(!VIRK__^LR``@`WNPV`&T`?KD6`"+&(````'&Y!``KP.7_
M_^?XUS>P.+`X0H"P<T*0L'?K&``8``Q"$+!PZQ@`$``,0A"P<>L9`!@`#$(0
ML'3KB``(``Q"@+!RZQD`$``,0A"P=>N9``@`#$*0L':Y!``KP.7__^?.T@.@
M`+`$N00`*](#H`2P#-(#H`BP%-(#H`RP'-(#H!"P).N/\.``!,#T___E8Z=(
M`#BY^3`D[$/_OH!VIRK__^LR``@`WNPV``H`?KD6`"+&(````!JG]/^NU_\0
M`!``01`1`*<V__NG]/_RU_\0`!``01`1`*<V__NG]/^/UP`0`!``UP`0`!``
M!P<'!P<'!P<'!P<'ZV_P,``DX^#P`/AQX_#P`/]QXP#_^``@N2$`_J<D__BY
M!`#^X_#^(/]QXP#QV``@LD\`$.,P\=@(<>L1`"``#;)/`!%!</#,XQ#PP``D
MN00`DM(',``0*,`0```U3+D$`#?`(```!BS21_#H$`C2#_#0$%#2!_#@$&#`
MY?__\K/L*``)`'RY!`"RE0`@`*=T`1[`Y?__XB/`Y?__X@#L*`#<`'SCL"``
M``*GA`#6IQD``.P[/+\`5:>$`,NG*0`/N0D`(^<"L```-Z<;`!#G```P`(&G
MA``,YP&P`$`&IQL`$.<``#``@:=T__CG,``'`"&YA``SN2``,D$@(`&YXB`2
MIR0`IN,A/_#_<>LB``$`#:<K``'`Y?__XE&5`+``XV"P``"4N00`TJ>$`!VY
M!`"MN00`*KD4`&;`4```!CJG2?__ISD``<#E___DN$&PL`%!H*`"XV"P``"4
ME0"P`*=T_^E!H/$(P"````7XI_0`":>K``CC(*_X_P*GA`"]N00`-\#E___R
M+KD$`++L*/_R`'R5`"``IX3_[<#E___RDNPH_^@`?KD$`"O`Y?__XP:Y!`!B
M["@`H`!\IQD``.PV/+\`5:>$`,^G*0`/N0D`(^<"8```-Z<;`!#G```P`(&G
MA``,YP%@`$`&IQL`$.<``#``@:=T__CG,``'`"&YA``SN2``,D$@(`&YXB`2
MIR0`JN,Q/_#_<:<I``#L33R_`%6GA`"GIQD`#[D)`!3G`=```#>G*P`0YP``
M,`"!IX0`G><"T`!`!J?T__:G*0`/I_3_0Z>H``"Y%``:ZQ$``P`-XR'PT``"
MIX0`(KD$`#>GJ@`!P.7___&U["C_[P!\E0`@`*>$_^K`Y?__XI>Y!`"R[";_
M#0!\N10`&NL1``,`#>,A\-```J=T_^*G*0`-P+````5ZP.7__^&`IV@`4[D$
M`-*G]/\TP.7___N[XQ#PP``$XR#QV`AQU0<@`!`HIW0`1;D$`"OK;_(0"`3`
M]/__XF2GJ```N10`&NL1``,`#>.Q\.@``J>$`"25`+``IX0`(+D$`"NGJ@`!
MP.7___'1["C_ZP!^N00`*\#E___B1;D$`&+L)O]"`'RY%``:ZQ$``P`-X['P
MZ``"IW3_X*=I``"G&0``[#8\OP!5IW3_-:<I``^G]/\_P.7__^+FIQD`#Z?T
M_V?G0``'`"&YA`!$N2``04$0$`&YXB`AIR3_\>,23_#_<1H3IQH$!+D4`+&Y
M!``KP.7__^$(X]#PL``DP!````3RXQ#PJ``DP!````2*XQ#PH``DN00`@J<Y
M``'`4```!/"G2?__P.7__^-MN00`**<Y`<#`Y?__XF;L)@`+_W[`Y?__XC!8
M$"``[!8!4!%^0=#Q,+D$`"BY!``]P.7__^+"&*+L)@`-`'Y8$/%(IRA``,`;
M``#P`.P2`"F`=L08```S3>-0D```!.,@$```!+D$`&C`0```!->G.0`!I[D`
M`,#E___BC^,0\,``!.,@\=@(<=4'(``0**=T_WVY!``KZV_R$`@$!_Y88/%,
MP.7__^`I[&+_U6!V6!#Q2*<H`<#`&P```?_L$O_+8':Y!``KP.7__^"'N00`
M-[D$`++`(```!,O`Y?__\)&Y!``R["@`WP!\XR"0```$P.7___5.N00`8NPH
M`-0`?*<9``#L-CR_`%6GA`#6IRD`#[D)`"/G`F```#>G&P`0YP``,`"!IX0`
M#.<!8`!`!J<;`!#G```P`(&G=/_XYS``!P`AN80`,[D@`#)!("`!N>(@$J<D
M`+'C(3_P_W'L+``@`WZY%``2P#````2$XQ%O_/]QIP@``+)=`#&G%/_^IW0`
M#^PH`9X$?J<J__NY%``B01)@`)4O$`"GA`&3Q!T``#*W[!@!<O]^[!@`K`!^
MP#````/YP"````.^P.7___*8P.7__^&9P!````2VXR#PJ``DXQ#PL``DP!``
M``.+XQ#PH``DN00`:+D$`"O`4```!$^G2?__ISD``<#E___B;*?T`#+`Y?__
MX3=8$"``IQX`$:=T`#/`Y?__X6ZGJ@`!N10`&N,0\+``).,@\*@`),`0```$
M@>,0\+@`),`0```#6>,0\*``)+D$`&BY!``KP%````0DITG__Z<Y``'`Y?__
MXCJY!``KISD!P,#E___A,^PH_\G_?KD$`"C`Y?__X?NY!``[P"````,GP.7_
M__(ON00`*\#E___YXJ?T_N_C8)````2G&0``[#8\OP!5IW3_+J<I``^G]/\X
MQ"@``#(7N10`$>,0\*``).-0D```!.,@(```!+D$`&C`0````WZG.0`!P.7_
M_^%6I[D``*?T_L7`$```,@OE3!````"Y!``FISD``,#E___AQ;D$`&(8<NPH
M_TT`?J=)``*G.?_NP.7__]]X09#QV+D$`":Y!``YITD`!L#E___A?94`\=BG
M=``&E4/QV:>$`06G20``ISD``+D$`":Y%`!WP.7__]]:IRD`@,#E___?-<`1
M9T4C`>,0(```),`?[\VKB>,0(`@`),`?F+K<_N,0(!``),`1$#)4=N5(("@`
M`.,0(!@`).5((#```,`?P]+A\.5,('@``.,0("``)+D$`**G]``+N00`.;D$
M`"JY%`!$P.7___K=I4^``+D$`#FY!``GP.7__^$HN00`0NPB_^P`?KD$`"?`
MY?__WLZY!``Z09#QQ+D$`*VY!``IIWD`%,#E___[5>-@D```D+D$`"JGFP`!
MIZL``L!0```"T*=)__^G.0`!P.7__^%.IW?_[<`0```#>9(`\5CC$/"P`"1!
M$/$PXQ#PJ``DN00`:+D$`"O`$````D;C$/"@`"3`4````P:G2?__ISD``<#E
M___A*Z?T_ONY!``WP"````)3P.7__^ZU["C_+P!\XQ`@``"4[!C_*0!^[!C_
M)C!^P!```#$NY4P0```!I_3^>N,0D`@``J>$_FRG*0``[$$\OP!5IX0`/:<Y
M``^Y"0`TYP,0```WIRL`$.<``#``@:>$``SG`A``0`:G*P`0YP``,`"!IW3_
M^.=```<`(;F$`$2Y(`!#03`P`;GB(".G)``8XR)/\/]Q["S^.P-]XS(?_/]Q
MIP@``,`@```"G[)=`".G%/_^N>*`8:?T_BJG.0`/I_3_T95!\=JG=/[[E4/Q
MVZ=T_O>52/'<IW3^\Y5%\=VG=/[ON00`)J=)``*G.?_&P.7__]Y)N00`)KD$
M`#FG20`IP.7__^!0P!````+-XY#PJ``DXQ#PL``DN00`:+D$`"NG]/]8!P<'
M!^M_\#@`),2X```P:;)/`)#C(+```!;KF0`@``VR3P"1X_#_4/]Q08#PI-('
M\*B0*,#E___@!+D$`*+C(+```!;`Y?__W_S2`""QH+"Y!``XP"````&%P.7_
M_^WU["@`!P!\E3$@`*>$`,_`Y?__]//C(+```!;`Y?__W^&G60`#ITD``<`P
M```"-L#E___>)[D$`*+L*``?`'SC(+```!;`Y?__W\SC$*`0``3`0````B/C
M,!````3`Y?__WB#C$*`0``3C$!````210!`-IW0`M>,@L```%L#E___?L*=9
M``.G20`!P#````()P.7__]WVN00`HNPH`"(`?+D$`#C`(````1+`Y?__[9U8
M$+``N00`<KD6`"'L>`!\`'S`Y?__WXWC$*`0``2Y!`!'XS`0```$P.7__]WB
MXR"P```6P.7__]]\N00`HN,@L```%L#E___?=*=)``'`,````=#`Y?__W/S`
M0````=6Y!``RN00`*L#E___=PN,@L```%L#E___?7)(`(+&Y!``XP"````#&
MP.7__^U6Q"L``#`CN00`LNPH`!P`?+D$`"NG.0'`P.7__]ZS["@`"1%^[!(`
M`0#8[!(`2P%_U0?PJ)`HIW0`5>M_\.@`!`?^Q"@``"_^P.7___H_Q"L``"_\
MN00`LNPF_]P`?,`@```!C\#E___?+94`(`&GA/\TI_3_+\#E___?%.,@H!``
M!,08```OWN,@(```!.,P$```!,#E___O`:?T_X/C(+```!;`Y?__WOWC$*`0
M``3C,!````3`Y?__WI2G]/\^Q!@``"^_N00`4N,P$```!+D$`$O`(````67`
MY?__WO+`Y?__WH_$6```+V3`]/__W-D'!P<'ZV_P,``DN00`'Z?[_V#C$/``
M`"3`P```+BX'!^-`\1``!.MO\-``!`?T!P<``@`!)7,O)7,`1'EN84QO861E
M<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4```O<')O
M8R]S96QF+V5X90``+W!R;V,O)6DO)7,`97AE`"X`4$%27U1%35```%!!4E]0
M4D]'3D%-10``.@`O`%!%4DPU3$E"``!015),3$E"`%!%4DPU3U!4``!015),
M24\``%!!4E])3DE424%,25I%1`!005)?4U!!5TY%1`!005)?0TQ%04X`4$%2
M7T1%0E5'`%!!4E]#04-(10!005)?1TQ/0D%,7T1%0E5'``!005)?1TQ/0D%,
M7U1-4$1)4@!005)?5$U01$E2``!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!
M3%]#3$5!3@``,0!,1%],24)205)97U!!5$@`<&%R+0``+64``"TM``!365-4
M14T``"4P,G@``"5S)7,E<R5S```E<SH@8W)E871I;VX@;V8@<')I=F%T92!S
M=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*```E<SH@<')I=F%T
M92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET
M(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*``!0051(``!P87)L```N<&%R
M```E<R5S8V%C:&4M)7,E<P``)7,E<W1E;7`M)74E<P`E<R5S=&5M<"TE=2TE
M=25S```8`'!E<FP``#``4$%2.CI086-K97(Z.E9%4E-)3TX``#$N,#4U`%5N
M86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y```E<SH@8W)E871I;VX@
M;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N
M;STE:2D*``!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB
M)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A
M8VMA9V4@7U]P87)?<&P["FUY("@D4$%27TU!1TE#+"`D<&%R7W1E;7`L("1P
M<F]G;F%M92P@0'1M<&9I;&4L("5-;V1U;&5#86-H92D["D5.1"![(&EF("@D
M14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E
M($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY("1T;W!D
M:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S
M*'%Q6U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B72D["D9I;&4Z.D9I
M;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]
M+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E
M;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z
M.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"
M87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*
M54Y,24Y+(#T^(#`L"BD["FUY("1F:6QE;F%M92`]("1T;7`M/F9I;&5N86UE
M.PIP<FEN="`D=&UP(#P\(BXN+B(["G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P
M(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA("UD("<D<&%R7W1E
M;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@
M"F1O;F4*<FT@)R1F:6QE;F%M92<*+BXN"F-L;W-E("1T;7`["F-H;6]D(#`W
M,#`L("1F:6QE;F%M93L*;7D@)&-M9"`]("(D9FEL96YA;64@/B]D978O;G5L
M;"`R/B8Q("8B.PIS>7-T96TH)&-M9"D["F]U=',H<7%;4W!A=VYE9"!B86-K
M9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`D9FEL96YA;65=
M*3L*?0I]('T*0D5'24X@>PHD4$%27TU!1TE#(#T@(EQN4$%2+G!M7&XB.PI)
M;G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ
M4$%2.CI"3T]4.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D<75I970@
M/2`A)$5.5GM005)?1$5"54=].PIM>2`E<WES(#T@*`IP871H7W-E<"`@("`]
M/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@("`@
M/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z
M("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G
M7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PIO=71S*'%Q6UPD<')O
M9VYA;64@/2`B)'!R;V=N86UE(ETI.PI?<V5T7W!A<E]T96UP*"D["F]U=',H
M<7%;7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!](ETI.PIM>2`H
M)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*34%'24,Z('L*;&]C86P@)%-)1WM?
M7U=!4DY?7WT@/2!S=6(@>WT["G5N;&5S<R`H;W!E;B!?1D@L("<\.G)A=R<L
M("1P<F]G;F%M92D@>PIO=71S*'%Q6T-A;B=T(')E860@9G)O;2!F:6QE("(D
M<')O9VYA;64B72D[("`C(&1O;B=T('5S92`D(2!H97)E(&%S(&ET(')E<75I
M<F5S($5R<FYO+G!M"FQA<W0@34%'24,["GT*;7D@)&-H=6YK7W-I>F4@/2`V
M-"`J(#$P,C0["FUY("1B=68["FUY("1S:7IE(#T@+7,@7T9(.PIM>2`D;6%G
M:6-?<&]S(#T@)'-I>F4@+2`D<VEZ92`E("1C:'5N:U]S:7IE.R`C($Y/5$4Z
M("1M86=I8U]P;W,@:7,@82!M=6QT:7!L92!O9B`D8VAU;FM?<VEZ90IW:&EL
M92`H)&UA9VEC7W!O<R`^/2`P*2!["G-E96L@7T9(+"`D;6%G:6-?<&]S+"`P
M.PIR96%D(%]&2"P@)&)U9BP@)&-H=6YK7W-I>F4@*R!L96YG=&@H)%!!4E]-
M04=)0RD["FEF("@H;7D@)&D@/2!R:6YD97@H)&)U9BP@)%!!4E]-04=)0RDI
M(#X](#`I('L*)&UA9VEC7W!O<R`K/2`D:3L*;&%S=#L*?0HD;6%G:6-?<&]S
M("T]("1C:'5N:U]S:7IE.PI]"FEF("@D;6%G:6-?<&]S(#P@,"D@>PIO=71S
M*'%Q6T-A;B=T(&9I;F0@;6%G:6,@<W1R:6YG("(D4$%27TU!1TE#(B!I;B!F
M:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'24,["GT*;W5T<R@B1F]U;F0@
M4$%2(&UA9VEC(&%T('!O<VET:6]N("1M86=I8U]P;W,B*3L*<V5E:R!?1D@L
M("1M86=I8U]P;W,@+2`T+"`P.PIR96%D(%]&2"P@)&)U9BP@-#L*;7D@)&]F
M9G-E="`]('5N<&%C:R@B3B(L("1B=68I.PIO=71S*")/9F9S970@9G)O;2!S
M=&%R="!O9B!&24Q%<R!I<R`D;V9F<V5T(BD["G-E96L@7T9(+"`D;6%G:6-?
M<&]S("T@-"`M("1O9F9S970L(#`["B1D871A7W!O<R`]('1E;&P@7T9(.PIM
M>2`E<F5Q=6ER95]L:7-T.PIR96%D(%]&2"P@)&)U9BP@-#L@("`@("`@("`@
M("`@("`@("`@("`@("`@("`C(')E860@=&AE(&9I<G-T(")&24Q%(@IW:&EL
M92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E860@
M7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@
M)&)U9CL*;W5T<RAQ<5M5;G!A8VMI;F<@1DE,12`B)&9U;&QN86UE(BXN+ETI
M.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\
M("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F
M(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F+"`T
M.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD969I
M;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@
M>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&-R8R1E>'0B+"`D8G5F+"`P
M-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I
M;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D
M9G5L;&YA;64["GT*96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\
M(&%N9"!D969I;F5D("1%3E9[4$%27U1%35!]("D@>PIM>2`D9FEL96YA;64@
M/2!?<V%V95]A<R@B)&)A<V5N86UE)&5X="(L("1B=68L(#`W-34I.PIO=71S
M*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*?0IE;'-E('L*)$UO9'5L94-A8VAE
M>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M
M92`]/B`D9G5L;&YA;64L"GT["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2LK
M.PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*
M;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U
M;&4@;W(@(21M;V1U;&4["FUY("1I;F9O(#T@)$UO9'5L94-A8VAE>R1M;V1U
M;&5].PIR971U<FX@=6YL97-S("1I;F9O.PID96QE=&4@)')E<75I<F5?;&ES
M='LD;6]D=6QE?3L*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M
M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ
M1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@
M;W(@9&EE(")#86XG="!C<F5A=&4@=&5M<"!F:6QE.B`D(2(["B1F:"T^8FEN
M;6]D92@I.PHD9F@M/G!R:6YT*"1I;F9O+3Y[8G5F?2D["B1F:"T^<V5E:R@P
M+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@7W-A
M=F5?87,H(B1I;F9O+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F?2D["B1I;F9O
M+3Y[9FEL97T@/2`D9FEL96YA;64["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D
M9FEL96YA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE;F%M92(Z("0A
M73L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C
M86XG="!F:6YD(&UO9'5L92`D;6]D=6QE(2(["GTL($!)3D,I.PIR97%U:7)E
M(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ
M2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?
M:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM
M>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2![
M"G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$
M4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER
M92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I
M;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R
M97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0IU;FQE<W,@*"1B=68@97$@(E!+
M7#`P,UPP,#0B*2!["F]U=',H<7%;3F\@>FEP(&9O=6YD(&%F=&5R($9)3$4@
M<V5C=&EO;B!I;B!F:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'24,@.PI]
M"B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L@("`@("`@("`@("`@("`@
M(R!S=&%R="!O9B!Z:7`*?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N
M9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*9&5L971E("1%3E9[4$%27T%0
M4%]2155317T[(",@<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y
M('!R;V)L96TI"B1Q=6EE="`](#`@=6YL97-S("1%3E9[4$%27T1%0E5'?3L*
M:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N
M<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T
M;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S
M:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=6
M6S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!0
M7U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L
M(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!
M4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0[
M"FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS
M:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E
M<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E
M<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U
M;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@
M/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*
M96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@
M9&EE('%Q6T-A;B=T(&]P96X@;&]G(&9I;&4@(B0R(CH@)"%=.PI]"F5L<VEF
M("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'
M5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.
M5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0[
M"B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z
M.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF
M="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER
M92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG
M97-T.CI32$$["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*
M:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)'!A
M<B!O<B!D:64@<7%;0V%N)W0@9FEN9"!P87(@9FEL92`B)'!A<B(Z("0A73L*
M8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^
M;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]
M($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D
M:6YG('II<"!A<F-H:79E("(D<&%R(ET["GT*:68@*&1E9FEN960@)'!A<BD@
M>PIO<&5N(&UY("1P:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@
M<F5A9"!P87(@9FEL92`B)'!A<B(Z("0A73L*;7D@)&)U9CL*<F5A9"`D<&@L
M("1B=68L(#0["F1I92!Q<5LB)'!A<B(@:7,@;F]T(&$@<&%R(&9I;&5=('5N
M;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*8VQO<V4@)'!H.PI]"D-R96%T
M95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)
M3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)
M3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92!Q<5M#86XG="!C
M<F5A=&4@9FEL92`B)&]U="(Z("0A73L*)&9H+3YB:6YM;V1E*"D["G-E96L@
M7T9(+"`P+"`P.PIM>2`D;&]A9&5R.PII9B`H9&5F:6YE9"`D9&%T85]P;W,I
M('L*<F5A9"!?1D@L("1L;V%D97(L("1D871A7W!O<SL*?2!E;'-E('L*;&]C
M86P@)"\@/2!U;F1E9CL*)&QO861E<B`](#Q?1D@^.PI]"FEF("@A)$5.5GM0
M05)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@
M>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z
M.E!O9%-T<FEP+3YA<'!L>2A<)&QO861E<BP@)#`I.PI]"B1F:"T^<')I;G0H
M)&QO861E<BD*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@;&]A9&5R('1O("(D
M;W5T(CH@)"%=.PII9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD[
M"E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*
M<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P('L@(2]"4T1004XO
M('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(**"1?(&YE("1#;VYF
M:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N
M9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIS?"\K?"]\9RP@<WPO)'Q\(&9O
M<F5A8V@@0&EN8SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA
M3&]A9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L
M:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].R`@("`@("`@(",@
M6%A8(&QI8E]E>'0@=G,@9&QE>'0@/PIM>2`E=W)I='1E;CL*9F]R96%C:"!M
M>2`D:V5Y("AS;W)T(&ME>7,@)69I;&5S*2!["FUY("@D9FEL92P@)&YA;64I
M.PII9B`H9&5F:6YE9"AM>2`D9F,@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE
M>R1K97E]*2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D9F,I.PI]"F5L
M<V4@>PIF;W)E86-H(&UY("1D:7(@*$!I;F,I('L*:68@*"1K97D@/7X@;7Q>
M7%$D9&ER7$4O*"XJ*21\:2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D
M,2D["FQA<W0["GT*:68@*"1K97D@/7X@;7Q>+VQO861E<B];7B]=*R\H+BHI
M)'PI('L*:68@*&UY("1R968@/2`D36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL
M92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0II9B`H+68@(B1D:7(O
M)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T
M.PI]"GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64["FYE>'0@:68@
M)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F
M:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O:3L*;W5T<RAS<')I;G1F*'%Q6U!A
M8VMI;F<@1DE,12`B)7,B+BXN72P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE
M?2`Z("1F:6QE*2D["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD
M8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;&]C86P@)"\@/2!U
M;F1E9CL*;W!E;B!M>2`D=&@L("<\.G)A=R<L("1F:6QE(&]R(&1I92!Q<5M#
M86XG="!R96%D("(D9FEL92(Z("0A73L*)&-O;G1E;G0@/2`\)'1H/CL*8VQO
M<V4@)'1H.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD8V]N=&5N
M="P@(CQE;6)E9&1E9#XO)&YA;64B*0II9B`A)$5.5GM005)?5D520D%424U]
M(&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R
M.CI0871C:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92P@
M)&YA;64I.PI]"B1F:"T^<')I;G0H(D9)3$4B+`IP86-K*"=.)RP@;&5N9W1H
M*"1N86UE*2`K(#DI+`IS<')I;G1F*"(E,#AX+R5S(BP@07)C:&EV93HZ6FEP
M.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M92DL"G!A8VLH)TXG+"!L
M96YG=&@H)&-O;G1E;G0I*2P*)&-O;G1E;G0I"F]R(&1I92!Q<5M%<G)O<B!W
M<FET:6YG(&5M8F5D9&5D($9)3$4@=&\@(B1O=70B.B`D(5T["F]U=',H<7%;
M5W)I='1E;B!A<R`B)&YA;64B72D["GT*?0II9B`H)'II<"D@>PHD>FEP+3YW
M<FET951O1FEL94AA;F1L92@D9F@I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TL*
M;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@>FEP('!A<G0@;V8@(B1O=70B73L*
M?0HD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`["FEF
M("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I*5LY
M72D@>PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*;W!E;B!M>2`D
M=&@L("(\.G)A=R(L("1O=70["B1C='@M/F%D9&9I;&4H)'1H*3L*8VQO<V4@
M)'1H.PHD8V%C:&5?;F%M92`]("1C='@M/FAE>&1I9V5S=#L*?0HD8V%C:&5?
M;F%M92`N/2`B7#`B('@@*#0P("T@;&5N9W1H("1C86-H95]N86UE*3L*)&-A
M8VAE7VYA;64@+CT@(EPP0T%#2$4B.PIM>2`D;V9F<V5T(#T@)&9H+3YT96QL
M("L@;&5N9W1H*"1C86-H95]N86UE*2`M(&QE;F=T:"@D;&]A9&5R*3L*)&9H
M+3YP<FEN="@D8V%C:&5?;F%M92P*<&%C:R@G3B<L("1O9F9S970I+`HD4$%2
M7TU!1TE#*0HF)B`D9F@M/F-L;W-E"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG
M('1R86EL97(@;V8@(B1O=70B.B`D(5T["F-H;6]D(#`W-34L("1O=70["F5X
M:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?
M<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y
M;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C
M:&EV93HZ6FEP.PI]"FUY("1F:"`]($E/.CI&:6QE+3YN97<[("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`C($%R8VAI=F4Z.EII<"!O<&5R871E<R!O
M;B!A;B!)3SHZ2&%N9&QE"B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I
M(&]R(&1I92!Q<5MF9&]P96XH*2!F86EL960Z("0A73L*07)C:&EV93HZ6FEP
M.CIS971#:'5N:U-I>F4H+7,@7T9(*3L*;7D@)'II<"`]($%R8VAI=F4Z.EII
M<"T^;F5W.PHH)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N
M86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O
M<B!R96%D:6YG('II<"!A<F-H:79E("(D<')O9VYA;64B73L*07)C:&EV93HZ
M6FEP.CIS971#:'5N:U-I>F4H-C0@*B`Q,#(T*3L*)'%U:65T(#T@(21%3E9[
M4$%27T1%0E5'?3L*;W5T<R@B4F5A9&EN9R!-151!+GEM;"XN+B(I.PII9B`H
M;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T
M82`]?B!S+RXJ7G!A<CI<<RHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,[
M"FEF("AM>2`H)&-L96%N*2`]("1M971A(#U^("]>7',K8VQE86XZ("@N*BDD
M+VTI('L*)&-L96%N(#U^("]>7',J?%QS*B0O9SL*)$5.5GM005)?0TQ%04Y]
M(#T@,2!I9B`D8VQE86X["GT*?0IP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP
M.PHD4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*;W5T<R@B17AT
M<F%C=&EN9R!Z:7`N+BXB*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI
M('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@
M)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^
M:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.
M86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB
M+PHH/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\**#\Z)$-O;F9I9SHZ
M0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T
M7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I
M;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E
M<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H
M*2D@>PIO=71S*'%Q6U-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET
M(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(ETI.PI](&5L<V4@>PIO
M=71S*'%Q6T5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA
M;64B+BXN72D["B@D;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?
M;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R
M;W(@97AT<F%C=&EN9R!Z:7`@;65M8F5R('1O("(D9&5S=%]N86UE(ET["F-H
M;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]
M"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\
M/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;
M("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP
M;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM0
M05)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD[
M"GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@
M1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]
M($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*
M<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I
M('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]
M"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$
M>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR
M97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*
M<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%
M>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N
M=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR
M97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ
M2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:
M;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(
M03L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!0
M05(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U
M:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB
M=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I
M;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@
M<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I
M<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@
M4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U
M:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D
M("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I
M('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H
M("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$
M25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X
M="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P
M871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@
M/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H
M)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO
M9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE
M(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%
M?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"B1U<V5R;F%M92`]?B!S
M+UQ7+U\O9SL*;7D@)'-T;7!D:7(@/2`B)'!A=&@D<WES>U]D96QI;7UP87(M
M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W
M-34["FEF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H<W1A
M="@D<')O9VYA;64I*5LY72D@>PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@)'!R
M;V=N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D<')O9VYA;64B.B`D(5T[
M"G-E96L@)&9H+"`M,3@L(#(["FUY("1B=68["G)E860@)&9H+"`D8G5F+"`V
M.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("TU."P@,CL*
M<F5A9"`D9F@L("1B=68L(#0Q.PHD8G5F(#U^(',O7#`O+V<["B1S=&UP9&ER
M("X]("(D<WES>U]D96QI;7UC86-H92TD8G5F(CL*?0IE;'-E('L*;7D@)&1I
M9V5S="`](&5V86P*>PIR97%U:7)E($1I9V5S=#HZ4TA!.PIM>2`D8W1X(#T@
M1&EG97-T.CI32$$M/FYE=R@Q*3L*;W!E;B!M>2`D9F@L("(\.G)A=R(L("1P
M<F]G;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)'!R;V=N86UE(CH@)"%=
M.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["B1C='@M/FAE>&1I
M9V5S=#L*?2!\?"`D;71I;64["B1S=&UP9&ER("X]("(D<WES>U]D96QI;7UC
M86-H92TD9&EG97-T(CL*?0IC;&]S92@D9F@I.PI]"F5L<V4@>PHD14Y6>U!!
M4E]#3$5!3GT@/2`Q.PHD<W1M<&1I<B`N/2`B)'-Y<WM?9&5L:6U]=&5M<"TD
M)"(["GT*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;6MD:7(@)'-T;7!D
M:7(L(#`W-34["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?
M5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS=6(@7W-A
M=F5?87,@>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I(#T@0%\["FUY
M("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@*"UE("1F
M=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D(CL*;7D@
M)&9H.PHH;W!E;B`D9F@L("<^.G)A=R<L("1T96UP;F%M92D*)B8@*'!R:6YT
M("1F:"`D8V]N=&5N=',I"B8F("AC;&]S92`D9F@I"F]R(&1I92!Q<5M%<G)O
M<B!W<FET:6YG("(D=&5M<&YA;64B.B`D(5T["F-H;6]D("1M;V1E+"`D=&5M
M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M92P@)&9U
M;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@)&9U;&QN
M86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM0
M05)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO
M*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D
M14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]4
M14U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R
M:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI("L@,2D["GT*:68@*"$D
M14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D<WES>U]D
M96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M
M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE)'-Y
M<WM?97AE?2(I('L*)'!R;V=N86UE("X]("1S>7-[7V5X97T["G)E='5R;CL*
M?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)'-Y<WMP871H7W-E<'U<
M12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-
M4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@<R]<421S
M>7-[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)'-Y<WM?9&5L
M:6U])'!R;V=N86UE)'-Y<WM?97AE?2(I+"!L87-T*0II9B`M<R`B)&1I<B1S
M>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X97TB.PHH*"1P<F]G;F%M92`]
M("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF("US("(D
M9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N
M86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*
M:68@*&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`\(#`I('L*)'!R
M;V=N86UE(#T@(BXD<WES>U]D96QI;7TD<')O9VYA;64B.PI]"FUY("1P=V0@
M/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H
M9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@
M<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<
M421S>7-[7V1E;&EM?5Q%*2\D<'=D)'-Y<WM?9&5L:6U]+SL*)$5.5GM005)?
M4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?96YV('L*
M:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR971U<FX[
M"GT@96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*9F]R("AQ
M=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%("D@
M*2!["F1E;&5T92`D14Y6>R)005)?)%\B?3L*?0IF;W(@*'%W+R!435!$25(@
M5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[(E!!4E\D7R)](#T@)$5.5GLB
M4$%27T=,3T)!3%\D7R)](&EF(&5X:7-T<R`D14Y6>R)005)?1TQ/0D%,7R1?
M(GT["GT*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#
M3$5!3GT["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970["FEF("@D
M;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*<')I;G0@
M(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U
M<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1?
M?2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E
M;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G
M92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN
M9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<5MP87(N<&PZ
M($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@
M9FEL92!O<B!D:7)E8W1O<GE<;ET*=6YL97-S("UE("1P<F]G;F%M93L*9&\@
M)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E4
M7UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)23U(@/2`D
M0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>
M7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?
M15)23U(["C$["E]?14Y$7U\*`%5315(``%5315).04U%``!414U01$E2`%1-
M4``O=&UP``!P97)L>'-I+F,````!&P,[````W````!K__W^(```%+/__@=@`
M``#X__^#"````2C__YGH```!:/__FL@```'(__^;6````?C__YU8```"-/__
MG=@```)P__^>V````K#__Z(H```"]/__HF@```,4__^C:````UC__Z-X```#
M;/__IC@```.L__^FB````\#__Z?X```#Y/__K8@```08__^N&```!$3__ZY(
M```$9/__K_@```3$__^P:```!.C__[%X```%;/__LJ@```6H__^T"```!>#_
M_[VH```&//__P"@```9X`````````!0``````7I2``%X#@$;#`^@`0<.````
M`!0````<__^`V````$(``````````````!0``````7I2``%X#@$;#`^@`0``
M`````#P````<__^!V```%MX`1H8.APV(#(D+B@J+"8P(C0>.!H\%2@[0!P,6
MQ@K/SLW,R\K)R,?&#J`!0@L```````!<````7/__F'@```#<`$:&#H<-B`R)
M"XH*BPF,"(T'C@:/!48.P`("F`K/SLW,R\K)R,?&#J`!0@M<"L_.S<S+RLG(
MQ\8.H`%""TX*S\[-S,O*R<C'Q@Z@`4(+```````L````O/__F/@```"0`$:*
M"HL)C`B-!XX&CP5*#M@#`G@*S\[-S,O*#J`!0@L````X````[/__F5@```'T
M`$:&#H<-B`R)"XH*BPF,"(T'C@:/!4H.X`-R"L_.S<S+RLG(Q\8.H`%""P``
M```X```!*/__FQP```!X`$:&#H<-B`R)"XH*BPF,"(T'C@:/!4P.R`("9,_.
MS<S+RLG(Q\8.H`$````````\```!9/__FV````$``$:'#8@,B0N*"HL)C`B-
M!XX&CP5&#J`A3`[((@+8"L_.S<S+RLG(QPZ@`4(+````````0````:3__YP@
M```#1`!&A@Z'#8@,B0N*"HL)C`B-!XX&CP5.#N`"2)@5`P*F"L_.S<S+RLG(
MQ\;8#J`!0@L````````<```!Z/__GRP````\`$R.!H\%1@[``F3/S@Z@`0``
M`$````((__^?3````/0`1H8.APV(#(D+B@J+"8P(C0>.!H\%1@Z@(4P.H$%,
M#MA"`L`*S\[-S,O*R<C'Q@Z@`4(+````$````DS__Z`(````!@`````````\
M```"8/__H`0```*^`$:&#H<-B`R)"XH*BPF,"(T'C@:/!48.H"%,#O`C`GH*
MS\[-S,O*R<C'Q@Z@`4(+````$````J#__Z*$````1``````````@```"M/__
MHL````%N``,!%HX&CP5&#L`"7,_.#J`!```````P```"V/__I`P```6,`$:*
M"HL)C`B-!XX&CP5*#M`"`P5&"L_.S<S+R@Z@`48+````````*````PS__ZEH
M````C`!&BPF,"(T'C@:/!4H.T`)P"L_.S<S+#J`!0@L````<```#./__J<P`
M```L`$:.!H\%1@[``E[/S@Z@`0```%P```-8__^IW````:0`1H8.APV(#(D+
MB@J+"8P(C0>.!H\%2@[@`@)6"L_.S<S+RLG(Q\8.H`%""UH*S\[-S,O*R<C'
MQ@Z@`48+`P$6S\[-S,O*R<C'Q@Z@`0```````"````.X__^K+````&P`2HX&
MCP5&#L`"`EK/S@Z@`0```````$````/<__^K>````0H`1HD+B@J+"8P(C0>.
M!H\%2@[0`@)V"L_.S<S+RLD.H`%""P)F"L_.S<S+RLD.H`%&"P``````/```
M!"#__WI4```"3@!&A@Z'#8@,B0N*"HL)C`B-!XX&CP5*#N@"`P&F"L_.S<S+
MRLG(Q\8.H`%""P```````#@```1@__^L!````3``1H8.APV(#(D+B@J+"8P(
MC0>.!H\%9`[``@*L"L_.S<S+RLG(Q\8.H`%""P```#0```2<__^L^````50`
M1H@,B0N*"HL)C`B-!XX&CP5L#L`"`L`*S\[-S,O*R<@.H`%&"P``````6```
M!-3__ZX@```)G`!&A@Z'#8@,B0N*"HL)C`B-!XX&CP5&#`Z@@0)8#0]&#H"%
M`@,"Q@K/SLW,R\K)R,?&#J`!1@L#`8H*S\[-S,O*R<C'Q@Z@`4(+```````X
M```%,/__MV0```*``$:'#8@,B0N*"HL)C`B-!XX&CP5@#M`"`P&T"L_.S<S+
MRLG(QPZ@`4(+```````0```%;/__N:@````,````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````D$```````
M`"/```````````$````````"UP`````````!`````````N<`````````#```
M`````!E8``````````T```````!A4``````````9````````N[``````````
M&P`````````(`````````!H```````"[N``````````<``````````@`````
M;__^]0````````*0``````````4````````,(``````````&`````````V@`
M````````"@````````1;``````````L`````````&``````````5````````
M`````````````P```````+W```````````(````````%*``````````4````
M``````<`````````%P```````!0P``````````<````````1J``````````(
M`````````H@`````````"0`````````8`````````!X`````````"`````!O
M___[``````@```$`````;____@```````!$X`````&____\``````````0``
M``!O___P````````$'P`````;___^0`````````0````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````"[P```````````````````````
M```````9Q@```````!GF````````&@8````````:)@```````!I&````````
M&F8````````:A@```````!JF````````&L8````````:Y@```````!L&````
M````&R8````````;1@```````!MF````````&X8````````;I@```````!O&
M````````&^8````````<!@```````!PF````````'$8````````<9@``````
M`!R&````````'*8````````<Q@```````!SF````````'08````````=)@``
M`````!U&````````'68````````=A@```````!VF````````'<8````````=
MY@```````!X&````````'B8````````>1@```````!YF````````'H8`````
M```>I@```````![&````````'N8````````?!@```````!\F````````'T8`
M```````?9@```````!^&````````'Z8````````?Q@```````!_F````````
M(`8````````@)@```````"!&````````(&8````````@A@``````````````
M````````````````````````````````````7L``````````````````````
M``````````````````````````````````````````````````#`>```````
M````````````(*```````````````````,`(_____P````````````"A!@``
M`````&'8``````````````````!B>````````&)\````````H/H```````!A
MW@```````*$"``````````````````"@Z@```````*#P````````````````
M``!D.D=#0SH@*%5B=6YT=2`Q,2XS+C`M-'5B=6YT=3$I(#$Q+C,N,```+G-H
M<W1R=&%B`"YI;G1E<G``+FYO=&4N9VYU+F)U:6QD+6ED`"YN;W1E+D%"22UT
M86<`+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N
M=2YV97)S:6]N7W(`+G)E;&$N9'EN`"YR96QA+G!L=``N:6YI=``N=&5X=``N
M9FEN:0`N<F]D871A`"YE:%]F<F%M95]H9'(`+F5H7V9R86UE`"YI;FET7V%R
M<F%Y`"YF:6YI7V%R<F%Y`"YD>6YA;6EC`"YG;W0`+F1A=&$`+F)S<P`N8V]M
M;65N=```````````````````````````````````````````````````````
M``````````````````````````````````````L````!``````````(`````
M```".`````````(X``````````\````````````````````!````````````
M```3````!P`````````"`````````D@````````"2``````````D````````
M````````````!```````````````)@````<``````````@````````)L````
M`````FP`````````(`````````````````````0``````````````#1O___V
M``````````(````````"D`````````*0`````````-@````%````````````
M```(```````````````^````"P`````````"`````````V@````````#:```
M``````BX````!@````(`````````"``````````8````1@````,`````````
M`@````````P@````````#"`````````$6P````````````````````$`````
M`````````$YO____``````````(````````0?````````!!\`````````+H`
M```%```````````````"``````````(```!;;____@`````````"````````
M$3@````````1.`````````!P````!@````$`````````"```````````````
M:@````0``````````@```````!&H````````$:@````````"B`````4`````
M``````````@`````````&````'0````$`````````$(````````4,```````
M`!0P````````!2@````%````%0`````````(`````````!@```!^`````0``
M```````&````````&5@````````96`````````!`````````````````````
M!```````````````>0````$`````````!@```````!F8````````&9@`````
M```'``````````````````````0`````````(````(0````!``````````8`
M```````@H````````""@````````0+`````````````````````0````````
M``````"*`````0`````````&````````85````````!A4``````````L````
M````````````````!```````````````D`````$``````````@```````&%\
M````````87P````````_F@````````````````````0``````````````)@`
M```!``````````(```````"A&````````*$8`````````-P`````````````
M```````$``````````````"F`````0`````````"````````H?@```````"A
M^`````````6P````````````````````"```````````````L`````X`````
M`````P```````+NP````````J[``````````"`````````````````````@`
M````````"````+P````/``````````,```````"[N````````*NX````````
M``@````````````````````(``````````@```#(````!@`````````#````
M````N\````````"KP`````````(`````!@``````````````"``````````0
M````T0````$``````````P```````+W`````````K<`````````"0```````
M``````````````@`````````"````-8````!``````````,```````#`````
M`````+```````````(`````````````````````(``````````````#<````
M"``````````#````````P(````````"P@````````!`H````````````````
M````"```````````````X0````$`````````,```````````````````L(``
M````````)0````````````````````$``````````0````$````#````````
M`````````````````````+"E`````````.H````````````````````!````
%````````
